@@ -26,6 +26,7 @@ from func import new_key_req, uniq
 from calculate.lib.utils import ip as ip
 from calculate.core.datavars import DataVarsCore
 from calculate.lib.utils.files import readFile
+from calculate.lib.utils.text import _u8
 import urllib2 as u2
 
 if hasattr(u2, "ssl"):
@@ -201,7 +202,7 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
             return 1
         with open(cert_path + '/req_id', 'w') as fc:
             fc.write(res)
-        print _("Your request ID = %s") % res
+        print _("Your request ID = %s") % _u8(res)
         return 0
 
     # get a signed certificate from another server
@@ -232,7 +233,6 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
 
         result = client.service.get_server_cert(req_id, md5sum)
         cert = result[0][0]
-        ca_root = result[0][1]
         if cert == '1':
             print _('The signature request was rejected!')
             return 1
@@ -248,6 +248,7 @@ def check_server_certificate(cert, key, cert_path, args, port, auto=False):
             return 1
         with open(cert_path + '/server.crt', 'w') as fc:
             fc.write(cert)
+        ca_root = result[0][1]
         os.unlink(cert_path + '/req_id')
         print _('Certificate saved. Your certificate ID = %s') % req_id
         with open(cert_path + '/ca_root.crt', 'w') as fd:
