@@ -19,12 +19,8 @@ from M2Crypto import RSA, X509, EVP, m2
 from calculate.lib.cl_lang import setLocalTranslate
 from binascii import hexlify
 import hashlib
+from calculate.lib.utils.text import _u8
 
-'''
-Copyright (c) 2016 Jesse Peterson
-Licensed under the MIT license. See the included LICENSE.txt file for details.
-'''
- 
 from M2Crypto import m2
 from M2Crypto.X509 import X509_Extension
 from ctypes import *
@@ -88,15 +84,15 @@ def makeRequest(pubkey, pkey, serv_host, port):
                 return x.replace(' ', '_').replace('\t', '_')
             return ""
 
-        _CN = raw_input(_('Hostname [%s] : ') % result_host_name)
+        _CN = raw_input(_('Hostname [%s] : ') % _u8(result_host_name))
         name.CN = _CN or result_host_name or ""
         _OU = raw_input(_('Organization unit: '))
         name.OU = cleardata(_OU)
         _O = raw_input(_('Organization name: '))
         name.O = cleardata(_O)
         network = _('Full network address (host:port)')
-        _L = raw_input(network + ' [%s:%d]: ' % (host_name, port))
-        name.L = cleardata(_L) or (host_name + ':' + str(port))
+        _L = raw_input(network + ' [%s:%d]: ' % (_u8(host_name), port))
+        name.L = cleardata(_L) or (_u8(host_name) + ':' + str(port))
         _ST = raw_input(_('City: '))
         name.ST = cleardata(_ST)
         _C = raw_input(_('Country (two letters only!): '))
